# Smart print
Save a few seconds with every print statement 

- Everytime you want to print something, you lose a few seconds to type in the name of the variable being printed
- Worse still, your IDE helps you autocomplete long variable names but does not complete in the comments
```

```

Enter smart print: 
```
from smartprint import smartprint as sprint

a = 25
sprint (a)
``` 

Output: 
```
a : 25
```


